# orator-annotate
Annotate Python Models with schema Information.

![Build](https://travis-ci.com/abhsag24/orator-annotate.svg?branch=master)

## Usage

    ```
        pynnotate --model-path=<Path To Your Moidels> --config-path=<Path To database config>
    ```

## Installation

    ```
        pip install pynnotate
    ```
    Or to build from source:

    ```
        python setup.py install
    ```
